Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-docs.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSarah German <sgerman@gitlab.com>2023-01-25 13:55:59 +0300
committerAchilleas Pipinellis <axil@gitlab.com>2023-01-25 13:55:59 +0300
commitd98ca853a5b291133ca76323616ce3dd9c34693c (patch)
tree572f74ee7a875995c55e6fc1b8b7dc87b135784c /scripts
parent911830a6ab2fd270880afef8f4735f31b6974bc8 (diff)
Rename ALGOLIA_SEARCH variable to be more generic
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/check-lunr-index.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/scripts/check-lunr-index.sh b/scripts/check-lunr-index.sh
index 2e368a38..591b1fcd 100755
--- a/scripts/check-lunr-index.sh
+++ b/scripts/check-lunr-index.sh
@@ -9,7 +9,7 @@ COLOR_RESET="\e[39m"
#
# - index_check: checks if the lunr.js index is built. There's two files when the
# index is built: 'lunr-index.json' and 'lunr-map.json'.
# - dev_check: when ALGOLIA_SEARCH is set to 'false' the div we're looking for
# is set to 'js-lunr-form'. Otherwise, it's set to 'docsearch' by default.
# This is defined in
# https://gitlab.com/gitlab-org/gitlab-docs/-/blob/83ebc0de813c6e916b522a9203a6182d7425dd20/content/index.erb#L20-24.
@@ -37,7 +37,7 @@ else
then
# shellcheck disable=2059
printf "${COLOR_RED}ERROR: lunr.js index is found, but not enabled!\n"
- printf " Did you forget to build the site with ALGOLIA_SEARCH='false'?\n"
+ printf " Did you forget to build the site with SEARCH_BACKEND='lunr'?\n"
# shellcheck disable=2059
printf " For more information, see https://gitlab.com/gitlab-org/gitlab-docs/-/blob/main/doc/docsearch.md#lunrjs-search${COLOR_RESET}\n"
exit 1;
@@ -9,7 +9,7 @@ COLOR_RESET="\e[39m"
# - index_check: checks if the lunr.js index is built. There's two files when the
# index is built: 'lunr-index.json' and 'lunr-map.json'.
-# - dev_check: when ALGOLIA_SEARCH is set to 'false' the div we're looking for
+# - dev_check: when SEARCH_BACKEND is set to 'lunr' the div we're looking for
# is set to 'js-lunr-form'. Otherwise, it's set to 'docsearch' by default.
# This is defined in